@@ -1,7 +1,7 @@
 from unittest import TestCase
 
-from src.service.markdown_file_service import MarkdownFileService
 from src.model.file_path import FilePath
+from src.service.markdown_file_service import MarkdownFileService
 
 
 class TestOpenMarkDown(TestCase):
@@ -9,7 +9,9 @@ class TestOpenMarkDown(TestCase):
         markdown = """\
         ![](./image/file/path)
         ![](./image/file/path)
-        ![test](./image/file/path)""".replace(" ", "")
+        ![test](./image/file/path)""".replace(
+            " ", ""
+        )
 
         markdown_file_service = MarkdownFileService(FilePath("./test/test.md"))
 
